prettify-element Demo

Highlight from text value:

Highlight text content:

# hello world you can write text [with links](http://example.com) inline or [link references][1]. * one _thing_ has *em*phasis * two __things__ are **bold** --- hello world =========== <this_is inline="xml"></this_is> > markdown is so cool so are code segments 1. one thing (yeah!) 2. two thing `i can write code`, and `more` wipee! [1]: http://example.com

Highlight using template: